@@ -56,6 +56,7 @@
 import contextlib
 from email.utils import formataddr
 from json import dumps, loads
+import logging
 
 import requests
 
@@ -63,6 +64,7 @@ from .. import exception
 from ..common import NotifyFormat, NotifyType
 from ..locale import gettext_lazy as _
 from ..utils.parse import is_email, parse_bool, parse_emails, validate_regex
+from ..utils.sanitize import sanitize_payload
 from .base import NotifyBase
 
 # Provide some known codes SparkPost uses and what they translate to:
@@ -138,7 +140,7 @@ class NotifySparkPost(NotifyBase):
     default_batch_size = 2000
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_sparkpost"
+    setup_url = "https://appriseit.com/services/sparkpost/"
 
     # Default Notify Format
     notify_format = NotifyFormat.HTML
@@ -377,29 +379,16 @@ class NotifySparkPost(NotifyBase):
         url = f"{SPARKPOST_API_LOOKUP[self.region_name]}/transmissions/"
 
         # Some Debug Logging
-        self.logger.debug(
-            "SparkPost POST URL:"
-            f" {url} (cert_verify={self.verify_certificate})"
-        )
-
-        if "attachments" in payload["content"]:
-            # Since we print our payload; attachments make it a bit too noisy
-            # we just strip out the data block to accomodate it
-            log_payload = {k: v for k, v in payload.items() if k != "content"}
-            log_payload["content"] = {
-                k: v
-                for k, v in payload["content"].items()
-                if k != "attachments"
-            }
-            log_payload["content"]["attachments"] = [
-                {k: v for k, v in x.items() if k != "data"}
-                for x in payload["content"]["attachments"]
-            ]
-        else:
-            # No tidying is needed
-            log_payload = payload
-
-        self.logger.debug(f"SparkPost Payload: {log_payload}")
+        if self.logger.isEnabledFor(logging.DEBUG):
+            # Due to attachments; output can be quite heavy and io intensive
+            # To accommodate this, we only show our debug payload information
+            # if required.
+            self.logger.debug(
+                "SparkPost POST URL:"
+                f" {url} (cert_verify={self.verify_certificate})"
+            )
+            self.logger.debug(
+                "SparkPost Payload: %s", sanitize_payload(payload))
 
         wait = None
 
@@ -482,7 +471,8 @@ class NotifySparkPost(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 if status_code == requests.codes.too_many_requests and retry:
                     retry = retry - 1
@@ -684,7 +674,7 @@ class NotifySparkPost(NotifyBase):
                 payload["content"]["headers"] = headers
 
             # Send our message
-            status_code, response = self.__post(
+            status_code, _response = self.__post(
                 payload, self.sparkpost_retry_attempts
             )
 
